@@ -1,8 +1,7 @@
 #' @template dbispec
 #' @format NULL
 spec_transaction <- c(
-  spec_transaction_begin_commit,
-  spec_transaction_begin_rollback,
+  spec_transaction_begin_commit_rollback,
   spec_transaction_with_transaction,
 
   NULL
